GiniClust3
GiniClust3 is a a fast and memory-saving rare cell cluster identification method for large scale single-cell gene expression data.

## Prerequisites
* numpy (https://numpy.org/)
* scikit-learn (https://scikit-learn.org/stable/)
* scipy (https://www.scipy.org/)
* statsmodels (https://www.statsmodels.org/stable/index.html)
* anndata (https://anndata.readthedocs.io/en/stable/)
* scanpy (https://scanpy.readthedocs.io/en/stable/)

## Installation
pip install giniclust3
